@@ -5,7 +5,7 @@ use warnings;
 package LINQ::Collection;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.000_003';
+our $VERSION   = '0.000_004';
 
 use Role::Tiny;
 use LINQ::Util::Internal ();
@@ -190,14 +190,27 @@ sub take_while {
 	my $self    = shift;
 	my $filter  = LINQ::Util::Internal::assert_code( @_ );
 	my $stopped = 0;
-	$self->where(
-		sub {
-			$stopped = 1
-				if !$stopped
-				&& !$filter->( $_ );
-			not $stopped;
+	my $idx     = 0;
+	
+	require LINQ;
+	require LINQ::Iterator;
+	'LINQ::Iterator'->new( sub {
+		local ( $@, $_ );
+		my $next;
+		my $ok = eval { $next = $self->element_at( $idx ); not $stopped };
+		my $e  = $@;
+		if ( $ok and $filter->( $_ = $next ) ) {
+			++$idx;
+			return $next;
 		}
-	);
+		if ( defined $e and not $ok ) {
+			require Scalar::Util;
+			die( $e ) unless Scalar::Util::blessed( $e );
+			die( $e ) unless $e->isa( 'LINQ::Exception::NotFound' );
+		}
+		$stopped = 1;
+		return LINQ::END();
+	} );
 } #/ sub take_while
 
 sub skip {
@@ -221,9 +234,33 @@ sub skip_while {
 } #/ sub skip_while
 
 sub concat {
-	my $self  = shift;
-	my $other = $_[0];
-	return LINQ::Util::Internal::create_linq( $self, [ $self->to_list, $other->to_list ] );
+	my @collections = @_;
+	my $idx = 0;
+	
+	require LINQ;
+	require LINQ::Iterator;
+	'LINQ::Iterator'->new( sub {
+		local ( $@, $_ );
+		my $next;
+		FIND_NEXT: {
+			return LINQ::END() if not @collections;
+			
+			my $ok = eval { $next = $collections[0]->element_at( $idx ); 1 };
+			my $e  = $@;
+			if ( $ok ) {
+				++$idx;
+				return $next;
+			}
+			elsif ( defined $e and not $ok ) {
+				require Scalar::Util;
+				die( $e ) unless Scalar::Util::blessed( $e );
+				die( $e ) unless $e->isa( 'LINQ::Exception::NotFound' );
+			}
+			shift @collections;
+			$idx = 0;
+			redo FIND_NEXT;
+		};
+	} );
 }
 
 sub order_by {
@@ -630,7 +667,8 @@ this interface.
 Many methods take a parameter "CALLABLE". This means they can accept a
 coderef, an object overloading C<< &{} >>, or an arrayref where the first
 item is one of the previous two things and the remainder are treated as
-arguments to curry to the first argument.
+arguments to curry to the first argument. A quoted regexp C<< qr/.../ >> can
+also be used as a callable.
 
 If using an arrayref, it is generally permissable to flatten it into a
 list, unless otherwise noted. An example of this can be seen in the
